@@ -2,11 +2,11 @@ use 5.008;
 use strict;
 use warnings;
 package BenchmarkAnything::Storage::Frontend::HTTP;
-BEGIN {
-  $BenchmarkAnything::Storage::Frontend::HTTP::AUTHORITY = 'cpan:SCHWIGON';
-}
+# git description: v0.008-3-g922af53
+
+our $AUTHORITY = 'cpan:SCHWIGON';
 # ABSTRACT: Access a BenchmarkAnything store via HTTP
-$BenchmarkAnything::Storage::Frontend::HTTP::VERSION = '0.008';
+$BenchmarkAnything::Storage::Frontend::HTTP::VERSION = '0.009';
 use Mojo::Base 'Mojolicious';
 
 require File::HomeDir; # MUST 'require', 'use' conflicts with Mojolicious
@@ -83,12 +83,18 @@ sub startup {
         $routes
             ->any('/api/v1/listnames/:pattern' => [pattern => qr/[^\/]+/])
             ->to('search#listnames', pattern => '');
+        $routes
+            ->any('/api/v1/listkeys/:pattern' => [pattern => qr/[^\/]+/])
+            ->to('search#listkeys', pattern => '');
         $routes
             ->any('/api/v1/hello')
             ->to('search#hello');
         $routes
             ->any('/api/v1/add')
             ->to('submit#add');
+        $routes
+            ->any('/api/v1/stats')
+            ->to('search#stats');
 }
 
 1;
@@ -109,7 +115,7 @@ Steffen Schwigon <ss5@renormalist.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Steffen Schwigon.
+This software is copyright (c) 2016 by Steffen Schwigon.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
