@@ -1,9 +1,7 @@
 package BenchmarkAnything::Storage::Frontend::HTTP::Controller::Search;
-BEGIN {
-  $BenchmarkAnything::Storage::Frontend::HTTP::Controller::Search::AUTHORITY = 'cpan:SCHWIGON';
-}
+our $AUTHORITY = 'cpan:SCHWIGON';
 # ABSTRACT: BenchmarkAnything - REST API - data query
-$BenchmarkAnything::Storage::Frontend::HTTP::Controller::Search::VERSION = '0.008';
+$BenchmarkAnything::Storage::Frontend::HTTP::Controller::Search::VERSION = '0.009';
 use Mojo::Base 'Mojolicious::Controller';
 
 
@@ -45,7 +43,30 @@ sub listnames
         my @pattern = $pattern ? ($pattern) : ();
         my $answer = $self->app->backend->list_benchmark_names(@pattern);
 
-        $self->render(json => $self->app->backend->list_benchmark_names(@pattern));
+        $self->render(json => $answer);
+}
+
+
+sub listkeys
+{
+        my ($self) = @_;
+
+        my $pattern = $self->param('pattern');
+
+        my @pattern = $pattern ? ($pattern) : ();
+        my $answer = $self->app->backend->list_additional_keys(@pattern);
+
+        $self->render(json => $answer);
+}
+
+
+sub stats
+{
+        my ($self) = @_;
+
+        my $answer = $self->app->backend->get_stats;
+
+        $self->render(json => $answer);
 }
 
 1;
@@ -97,13 +118,35 @@ as SQL LIKE pattern, i.e., it allows to use C<%> as wildcards.
 
 =back
 
+=head2 listkeys
+
+Returns a list of additional key names.
+
+Parameters:
+
+=over 4
+
+=item * pattern (STRING)
+
+If a pattern is provided it restricts the results. The pattern is used
+as SQL LIKE pattern, i.e., it allows to use C<%> as wildcards.
+
+=back
+
+=head2 stats
+
+Returns a hash with info about the storage, like how many data points,
+how many metrics, how many additional keys, are stored.
+
+Parameters: none
+
 =head1 AUTHOR
 
 Steffen Schwigon <ss5@renormalist.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Steffen Schwigon.
+This software is copyright (c) 2016 by Steffen Schwigon.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
